@@ -2,7 +2,7 @@
 
 /*
  * File "cd_disect.c" is part of the UDFclient toolkit.
- * File $Id: cd_disect.c,v 1.79 2015/08/05 18:26:28 reinoud Exp $ $Name:  $
+ * File $Id: cd_disect.c,v 1.80 2016/04/25 20:55:30 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -1036,6 +1036,7 @@ void dump_disc_information(void) {
 		if (nwa_valid)        printf("\t\tNext writable  : %d\n", next_writable_addr);
 		if (lra_valid)        printf("\t\tLast recorded  : %d\n", last_recorded_addr);
 		if (is_copy)	      printf("\t\tTrack is a copy\n");
+		if (is_damage)	      printf("\t\tTrack is damaged\n");
 		if (is_reserved)      printf("\t\tReserved or Complete track\n");
 		if (is_blank)	      printf("\t\tBlank track\n");
 		if (is_packet_or_inc) printf("\t\tPacket mode track\n");
@@ -1295,7 +1296,7 @@ void dump_formatted_toc(void) {
 
 void dump_raw_toc_pma_data(uint8_t *toc) {
 	int pos, data_length;
-	int cur_session, session, cntrl, addr, tno, point;
+	int cur_session, session, cntrl, addr, point;
 	int min, sec, frame, pmin, psec, pframe, nwa, lba, extent;
 
 	data_length = toc[1] | (toc[0] << 8);
@@ -1304,7 +1305,7 @@ void dump_raw_toc_pma_data(uint8_t *toc) {
 		session = read_cd_bcd(toc[pos+ 0]);
 		cntrl   = toc[pos+1] & 15;
 		addr    = toc[pos+1] >> 4;
-		tno     = read_cd_bcd(toc[pos+ 2]);
+		//tno     = read_cd_bcd(toc[pos+ 2]);
 		point   = read_cd_bcd(toc[pos+ 3]);
 		min     = read_cd_bcd(toc[pos+ 4]);
 		sec     = read_cd_bcd(toc[pos+ 5]);
@@ -1420,14 +1421,13 @@ char *atip_speed(int speed) {
 
 void dump_atip_data(uint8_t *toc) {
 	int pos, data_length;
-	int cur_session;
 	int writing_power, ref_speed, URU, disc_cdrw, disc_subtype, A1, A2, A3;
 	int lowest_clv_rec, highest_clv_rec;
 	int power_multi, target_y, rec_EW_ratio, hicap_cdr_min;
 	int min, sec, frame, pmin, psec, pframe;
 
 	data_length = toc[1] | (toc[0] << 8);
-	pos = 4; cur_session = 0;
+	pos = 4;
 
 	writing_power   = (toc[pos   ] >> 4) & 15;
 	ref_speed       =  toc[pos   ] & 7;
@@ -1728,6 +1728,7 @@ void dump_parameter_page(uint8_t *pos, uint8_t *change) {
 			printf("\t\tData block type     %s %s\n", prchange(change[4] & 15), print_data_block_type(data_block_type));
 			printf("\t\tTestwriting         %s %s\n", prchange(change[2] & 16), testwrite ? "On":"Off");
 			printf("\t\tLinksize            %s %d sectors (%s)\n", prchange(change[5]), link_size, linksize_valid ? "valid": "not valid (7)");
+			printf("\t\tZerolinking support %s %s\n", prchange(change[2] & 64), zerolinking ? "On":"Off");
 			printf("\t\tApplication code    %s %d\n", prchange(change[7] & 63), appl_code);
 			printf("\t\tSession format      %s %s\n", prchange(change[8]), print_session_format(session_format));
 			printf("\t\tUsing fixed packets %s %s\n", prchange(change[3] & 32), fixed_packets ? "On":"Off");
