@@ -2,7 +2,7 @@
 
 /*
  * File "udf_discinfo.c" is part of the UDFclient toolkit.
- * File $Id: udf_discop.c,v 1.79 2015/08/05 18:26:31 reinoud Exp $ $Name:  $
+ * File $Id: udf_discop.c,v 1.80 2016/04/25 21:01:40 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -36,6 +36,7 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/ioctl.h>
 #include <unistd.h>
 #include <assert.h>
 #include <dirent.h>
@@ -698,6 +699,9 @@ int udf_discinfo_get_disc_type(struct udf_discinfo *disc) {
 		return error;
 	}
 
+	/* shutup gcc */
+	feature_pers = feature_pers; feature_ver = feature_ver;
+
 	return 0;
 }
 
@@ -1054,6 +1058,10 @@ int udf_get_disc_info(struct udf_discinfo *disc) {
 	session = disc->num_sessions-1;
 	disc->session_end[session] = res[3] | (res[2]<<8) | (res[1]<<16) | (res[0]<<24);
 
+	/* shut up gcc */
+	disc_size = disc_size; first_track_last_session = first_track_last_session;
+	cntrl = cntrl; last_track = last_track;
+
 	return 0;
 }
 #undef res_len
